#!/bin/bash
#Run this after installing raspbian
#ssh pi@raspberrypi.local.
#(password is "raspberry")
#Paste these commands into the terminal or copy this script over and run it:
#	bash ./pisensor-2-runme.sh
sudo apt update
sudo apt full-upgrade
sudo apt install rpi-eeprom rpi-eeprom-images apg lshw bro broctl i2c-tools python3-pil python3-pip rsync screen tcpdump uhubctl

status Access maintenance #================
if [ -z "${user_pass}" ]; then
	user_pass=`apg -a 0 -m 16 -x 16 -M SNCL -E '015|' -n 1`
fi
if [ -z "${root_pass}" ]; then
	root_pass=`apg -a 0 -m 16 -x 16 -M SNCL -E '015|' -n 1`
fi
echo "Hostname: ${my_hostname}"
echo "User pass: ${user_pass}"
echo "Root pass: ${root_pass}"
echo "Press enter when you've written these down.  Neither contain zero, one, five, or vertical pipe."
read junk <&2

if [ -x /usr/sbin/chpasswd ]; then
	#Set passwords for this account and root
	echo "`whoami`:${user_pass}" | sudo chpasswd
	echo "root:${root_pass}" | sudo chpasswd
else
	#Set passwords for this account and root
	echo "$user_pass" | sudo passwd "`whoami`" --stdin
	echo "$root_pass" | sudo passwd "root" --stdin
fi

# Enable ssh ================
sudo touch /boot/ssh							#Seriously.
sudo update-rc.d ssh enable

# Remove packages ================
sudo apt-get -y remove claws-mail claws-mail-i18n \
libreoffice libreoffice-avmedia-backend-gstreamer libreoffice-base libreoffice-base-core libreoffice-base-drivers \
libreoffice-calc libreoffice-common libreoffice-core libreoffice-draw libreoffice-gtk libreoffice-gtk2 libreoffice-help-en-gb \
libreoffice-impress libreoffice-java-common libreoffice-l10n-en-gb libreoffice-librelogo libreoffice-math libreoffice-nlpsolver \
libreoffice-ogltrans libreoffice-pdfimport libreoffice-pi libreoffice-report-builder libreoffice-report-builder-bin \
libreoffice-script-provider-bsh libreoffice-script-provider-js libreoffice-script-provider-python libreoffice-sdbc-hsqldb \
libreoffice-sdbc-postgresql libreoffice-style-galaxy libreoffice-style-tango libreoffice-systray libreoffice-wiki-publisher \
libreoffice-writer \
minecraft-pi \
vlc vlc-bin vlc-data vlc-l10n vlc-plugin-base vlc-plugin-notify vlc-plugin-qt vlc-plugin-samba vlc-plugin-skins2 \
vlc-plugin-video-output vlc-plugin-video-splitter vlc-plugin-visualization \
wolfram-engine wolframscript

# py3 pi packages ================
sudo pip3 install RPI.GPIO
sudo pip3 install Adafruit-Blinka
sudo pip3 install adafruit-circuitpython-ssd1306

# Setup ================
sudo mkdir /var/toshow/
sudo cp -p 00-ai_hunter_logo_128-32x1.ppm /var/toshow/
sudo chown -R pi.pi /var/toshow/

echo -e '\n#Added by prep_pi_sensor' | sudo tee -a /etc/sysctl.conf >/dev/null
echo 'net.ipv6.conf.all.forwarding=0' | sudo tee -a /etc/sysctl.conf >/dev/null
echo 'net.ipv6.conf.eth0.disable_ipv6=1' | sudo tee -a /etc/sysctl.conf >/dev/null

echo 'dtparam=i2c_arm=on' | sudo tee -a /boot/config.txt >/dev/null

echo 'i2c-dev' | sudo tee -a /etc/modules >/dev/null


status Configure Bro #================
#Change log directory from /var/log/bro/ to /opt/bro/logs/
sudo sed -i.bak -e 's@^LogDir.*@LogDir = /opt/bro/logs/@' /etc/bro/broctl.cfg

#Configure node.cfg
sudo /usr/local/bin/gen-node-cfg.sh
#node.cfg change cores from 2 to 3
sudo sed -i.bak -e 's@^lb_procs.*@lb_procs=3@' /etc/bro/node.cfg

sudo sed -i.bak2 -e 's@^lb_method.*@lb_method=pf_ring\npin_cpus=1,2,3@' /etc/bro/node.cfg


if ! grep -q '^10\.0\.0\.0/8' /opt/bro/etc/networks.cfg ; then
	echo '10.0.0.0/8      Private IP space' | sudo tee -a /opt/bro/etc/networks.cfg >/dev/null
fi
if ! grep -q '^172\.16\.0\.0/12' /opt/bro/etc/networks.cfg ; then
	echo '172.16.0.0/12      Private IP space' | sudo tee -a /opt/bro/etc/networks.cfg >/dev/null
fi
if ! grep -q '^192\.168\.0\.0/16' /opt/bro/etc/networks.cfg ; then
	echo '192.168.0.0/16      Private IP space' | sudo tee -a /opt/bro/etc/networks.cfg >/dev/null
fi


if grep -q '^BroArgs' /opt/bro/etc/broctl.cfg ; then
	echo "WARNING: /opt/bro/etc/broctl.cfg contains a BroArgs line already, please manually insert the BPF filter." >&2
else
	echo "BroArgs = -f '(port 53 or not ((src net 10.0.0.0/8 or src net 172.16.0.0/12 or src net 192.168.0.0/16 or src net 169.254.0.0/16) and (dst net 10.0.0.0/8 or dst net 172.16.0.0/12 or dst net 192.168.0.0/16 or dst net 169.254.0.0/16)) )'" | sudo tee -a /opt/bro/etc/broctl.cfg >/dev/null
	#No need to do a sudo broctl deploy here - we do it unconditionally below
fi


#Install ja3 plugin (almost verbatim from rita's install.sh, only changed the following "local_path=..." line
local_path=/usr/share/bro/site/

sudo mkdir -p $local_path/ja3/

for one_file in __load__.bro intel_ja3.bro ja3.bro ja3s.bro ; do
	if [ ! -e $local_path/ja3/$one_file ]; then
		sudo curl -sSL "https://raw.githubusercontent.com/salesforce/ja3/cb29184df7949743c64fcb190c902dfe72523e38/bro/$one_file" -o "$local_path/ja3/$one_file"
	fi
done

if ! grep -q '^[^#]*@load \./ja3' $local_path/local.bro ; then
	echo '' | sudo tee -a $local_path/local.bro
	echo '#Load ja3 support libraries' | sudo tee -a $local_path/local.bro
	echo '@load ./ja3' | sudo tee -a $local_path/local.bro
fi







sudo cp -p pi_show.py gen-node-cfg.sh node.cfg-template /usr/local/bin/
sudo chown root.root /usr/local/bin/{pi_show.py,gen-node-cfg.sh,node.cfg-template}
sudo chmod 755 /usr/local/bin/{pi_show.py,gen-node-cfg.sh}

#Enable the following 4 lines if you dont want a graphical desktop and want to reclaim the ram
#echo 'gpu_mem=16' | sudo tee -a /boot/config.txt >/dev/null
#sudo update-rc.d lightdm disable
#echo "Disable desktop in boot options.  You'll be asked to reboot afterwards, say yes."
#sudo raspi-config

echo "Rebooting in 20 seconds"
sleep 20
sudo reboot

